@@ -1,4 +1,4 @@
-/*  $Id: ident.c 7585 2006-11-21 09:37:51Z eagle $
+/*  $Id: ident.c 9893 2015-06-14 10:05:50Z iulius $
 **
 **  Ident authenticator.
 */
@@ -81,7 +81,8 @@ main(int argc, char *argv[])
         die("did not get client information from nnrpd");
 
     /* Connect back to the client system. */
-    sock = network_connect_host(res->clientip, identport, res->localip);
+    sock = network_connect_host(res->clientip, identport, res->localip,
+                                DEFAULT_TIMEOUT);
     if (sock < 0) {
         if (errno != ECONNREFUSED)
             sysdie("cannot connect to ident server");
@@ -109,7 +110,7 @@ main(int argc, char *argv[])
 		got++;
     } while (buf[got] != '\n');
     buf[got] = '\0';
-    if (buf[got-1] == '\r')
+    if (got > 0 && buf[got-1] == '\r')
 	buf[got-1] = '\0';
 
     /* buf now contains the entire ident response. */
