@@ -1,4 +1,4 @@
-/*  $Id: buffchan.c 9911 2015-07-04 21:32:56Z iulius $
+/*  $Id: buffchan.c 10040 2016-07-31 20:01:43Z iulius $
 **
 **  Buffered file exploder for innd.
 */
@@ -122,10 +122,8 @@ SITEcloseall(void)
 */
 static void SITEopen(SITE *sp)
 {
-    int			e;
-
     if ((sp->F = xfopena(sp->Filename)) == NULL
-     && ((e = errno) != EACCES || chmod(sp->Filename, 0644) < 0
+     && (errno != EACCES || chmod(sp->Filename, 0644) < 0
       || (sp->F = xfopena(sp->Filename)) == NULL)) {
         syswarn("%s cannot fopen %s", sp->Name, sp->Filename);
 	if ((sp->F = fopen("/dev/null", "w")) == NULL)
@@ -179,9 +177,7 @@ SITEfind(char *Name, bool CanCreate)
 
     /* Fill in the structure for the new site. */
     sp->Name = xstrdup(Name);
-#pragma GCC diagnostic ignored "-Wformat-nonliteral"
     snprintf(buff, sizeof(buff), Format, Map ? MAPname(Name) : sp->Name);
-#pragma GCC diagnostic warning "-Wformat-nonliteral"
     sp->Filename = xstrdup(buff);
     if (BufferMode == 'u')
 	sp->Buffer = NULL;
