@@ -1,4 +1,4 @@
-/*  $Id: innxbatch.c 8921 2010-01-22 23:33:08Z iulius $
+/*  $Id: innxbatch.c 9841 2015-05-02 16:27:37Z iulius $
 **
 **  Transmit batches to remote site, using the XBATCH command
 **  Modelled after innxmit.c and nntpbatch.c
@@ -31,7 +31,6 @@
 #include "config.h"
 #include "clibrary.h"
 #include "portable/socket.h"
-#include "portable/time.h"
 #include <ctype.h>
 #include <errno.h>
 #include <fcntl.h>
@@ -40,6 +39,11 @@
 #include <syslog.h>
 #include <sys/stat.h>
 
+#ifdef HAVE_SYS_TIME_H
+# include <sys/time.h>
+#endif
+#include <time.h>
+
 /* Needed on AIX 4.1 to get fd_set and friends. */
 #ifdef HAVE_SYS_SELECT_H
 # include <sys/select.h>
@@ -54,7 +58,7 @@
 /*
 **  Global variables.
 */
-static bool		Debug = 0;
+static bool		Debug = false;
 static bool		STATprint;
 static char		*REMhost;
 static double		STATbegin;
@@ -287,7 +291,6 @@ CATCHinterrupt(int s)
 /*
 **  Mark that the alarm went off.
 */
-/* ARGSUSED0 */
 static void
 CATCHalarm(int s UNUSED)
 {
@@ -351,7 +354,7 @@ main(int ac, char *av[])
       /* NOTREACHED */
       break;
     case 'D':
-      Debug++;
+      Debug = true;
       break;
 #ifdef FROMSTDIN
     case 'i':
