@@ -1,4 +1,4 @@
-/*  $Id: map.c,v 1.11 2003/01/19 01:15:26 rra Exp $
+/*  $Id: map.c 7585 2006-11-21 09:37:51Z eagle $
 **
 */
 
@@ -6,8 +6,8 @@
 #include "clibrary.h"
 #include <errno.h>
 
-#include "libinn.h"
-#include "paths.h"
+#include "inn/libinn.h"
+#include "inn/paths.h"
 
 #include "map.h"
 
