@@ -1,4 +1,4 @@
-/*  $Id: nntpget.c 9695 2014-09-20 05:53:22Z iulius $
+/*  $Id: nntpget.c 10009 2016-05-05 12:39:19Z iulius $
 **
 **  Connect to a remote site, and get news from it to offer to our local
 **  server.  Read list on stdin, or get it via NEWNEWS command.  Writes
@@ -243,10 +243,9 @@ main(int ac, char *av[])
 	    if (stat(optarg, &Sb) < 0)
                 sysdie("cannot stat %s", optarg);
 	    gt = gmtime(&Sb.st_mtime);
-	    /* Y2K: NNTP Spec currently allows only two digit years. */
-	    snprintf(tbuff, sizeof(tbuff), "%02d%02d%02d %02d%02d%02d GMT",
-		    gt->tm_year % 100, gt->tm_mon + 1, gt->tm_mday,
-		    gt->tm_hour, gt->tm_min, gt->tm_sec);
+            snprintf(tbuff, sizeof(tbuff), "%04d%02d%02d %02d%02d%02d GMT",
+                     gt->tm_year + 1900, gt->tm_mon + 1, gt->tm_mday,
+                     gt->tm_hour, gt->tm_min, gt->tm_sec);
 	    Since = tbuff;
 	    break;
 	case 'n':
@@ -462,7 +461,7 @@ main(int ac, char *av[])
     if (Update) {
 	if ((F = fopen(Update, "w")) == NULL)
             sysdie("cannot update %s", Update);
-	fprintf(F, "got %ld offered %ld sent %ld rejected %ld\n",
+	fprintf(F, "got %lu offered %lu sent %lu rejected %lu\n",
 		STATgot, STAToffered, STATsent, STATrejected); 
 	if (ferror(F) || fclose(F) == EOF)
             sysdie("cannot update %s", Update);
