@@ -1,4 +1,4 @@
-/*  $Id: overchan.c 7585 2006-11-21 09:37:51Z eagle $
+/*  $Id: overchan.c 9695 2014-09-20 05:53:22Z iulius $
 **
 **  Add entries to the overview database.
 **
@@ -12,11 +12,15 @@
 
 #include "config.h"
 #include "clibrary.h"
-#include "portable/time.h"
 #include <errno.h>
 #include <syslog.h>
 #include <sys/stat.h>
 
+#ifdef HAVE_SYS_TIME_H
+# include <sys/time.h>
+#endif
+#include <time.h>
+
 #include "inn/innconf.h"
 #include "inn/messages.h"
 #include "inn/overview.h"
