@@ -1,4 +1,4 @@
-/*  $Id: expire.c 9019 2010-03-19 21:27:15Z iulius $
+/*  $Id: expire.c 10012 2016-05-05 12:41:10Z iulius $
 **
 **  Expire news articles.
 */
@@ -98,16 +98,7 @@ static int EXPsplit(char *p, char sep, char **argv, int count)
     while (*p == sep)
       ++p;
 
-    if (!*p)
-      return 0;
-
-    if (!p)
-      return 0;
-
-    while (*p == sep)
-      ++p;
-
-    if (!*p)
+    if (*p == '\0')
       return 0;
 
     for (i = 1, *argv++ = p; *p; )
