@@ -1,14 +1,14 @@
-/*  $Id: makehistory.c 9120 2010-09-26 11:37:05Z iulius $
+/*  $Id: makehistory.c 9896 2015-06-14 10:09:47Z iulius $
 **
 **  Rebuild history/overview databases.
 */
 
 #include "config.h"
 #include "clibrary.h"
-#include "portable/wait.h"
 #include <assert.h>
 #include <errno.h>
 #include <syslog.h>
+#include <sys/wait.h>
 #include <time.h>
 
 #include "inn/buffer.h"
@@ -417,7 +417,7 @@ static void
 ARTreadschema(bool Overview)
 {
     const struct cvector        *standardoverview;
-    const struct vector         *extraoverview;
+    struct vector               *extraoverview;
     ARTOVERFIELD                *fp;
     unsigned int                i;
 
@@ -474,6 +474,8 @@ ARTreadschema(bool Overview)
         }
 
 	ARTfieldsize = fp - ARTfields;
+        vector_free(extraoverview);
+
     }
     if (Bytesp == (ARTOVERFIELD *)NULL)
         Missfieldsize++;
@@ -710,10 +712,8 @@ DoArt(ARTHANDLE *art)
         }
     }
 
-    MessageID = (char *)NULL;
     Arrived = art->arrived;
     Expires = 0;
-    Posted = 0;
 
     if (!Msgidp->HasHeader) {
         warn("no Message-ID header in %s", TokenToText(*art->token));
@@ -938,7 +938,6 @@ main(int argc, char **argv)
 	}
     }
     argc -= optind;
-    argv += optind;
     if (argc) {
         fprintf(stderr, "%s", usage);
         exit(1);
