@@ -1,4 +1,4 @@
-/*  $Id: getlist.c 9691 2014-09-17 16:31:35Z iulius $
+/*  $Id: getlist.c 10014 2016-05-05 12:42:31Z iulius $
 **
 **  Send a LIST command to an NNTP server and print the results.
 */
@@ -237,8 +237,9 @@ main(int argc, char *argv[])
             break;
         case 'p':
             port = atoi(optarg);
-            if (port <= 0)
+            if (port == 0) {
                 die("%s is not a valid port number", optarg);
+            }
             break;
         case 'R':
             reader = true;
