@@ -1,4 +1,4 @@
-/*  $Id: rnews.c 9911 2015-07-04 21:32:56Z iulius $
+/*  $Id: rnews.c 10040 2016-07-31 20:01:43Z iulius $
 **
 **  A front-end for InterNetNews.
 **
@@ -170,14 +170,10 @@ Reject(const char *article, size_t length UNUSED, const char *reason,
     int fd;
 #endif	/* defined(DO_RNEWS_SAVE_BAD) */
 
-#pragma GCC diagnostic ignored "-Wformat-nonliteral"
     notice(reason, arg);
-#pragma GCC diagnostic warning "-Wformat-nonliteral"
     if (Verbose) {
 	fprintf(stderr, "%s: ", InputFile);
-#pragma GCC diagnostic ignored "-Wformat-nonliteral"
 	fprintf(stderr, reason, arg);
-#pragma GCC diagnostic warning "-Wformat-nonliteral"
 	fprintf(stderr, " [%.40s...]\n", article);
     }
 
@@ -499,7 +495,6 @@ UnpackOne(int *fdp, size_t *countp)
     int		gzip = 0;
     bool	HadCount;
     bool	SawCunbatch;
-    int		len;
 
     *countp = 0;
     for (SawCunbatch = false, HadCount = false; ; ) {
@@ -581,6 +576,8 @@ UnpackOne(int *fdp, size_t *countp)
 	}
 
 #if	defined(DO_RNEWSPROGS)
+        int len;
+
 	cargv[0] = UNPACK;
 	cargv[1] = NULL;
 	/* Ignore any possible leading pathnames, to avoid trouble. */
@@ -861,7 +858,14 @@ int main(int ac, char *av[])
        other setups where rnews might be setuid news or be run by other
        processes in the news group. */
     if (getuid() == 0 || geteuid() == 0) {
-        ensure_news_user(true);
+        uid_t uid;
+
+        /* Do not use ensure_news_user() because it will fail to deal
+         * with the case of rnews being setuid news. */
+        get_news_uid_gid(&uid, false, true);
+        if (setuid(uid) < 0) {
+            sysdie("failed to setuid");
+        }
     }
 
     if (!innconf_read(NULL))
