@@ -1,4 +1,4 @@
-/* $Id: clibrary.h 9763 2014-12-07 20:39:49Z iulius $
+/* $Id: clibrary.h 10099 2016-11-04 22:21:59Z iulius $
  *
  * Standard system includes and portability adjustments.
  *
@@ -24,7 +24,7 @@
  * the portable helper library.  Also provides some standard #defines.
  *
  * The canonical version of this file is maintained in the rra-c-util package,
- * which can be found at <http://www.eyrie.org/~eagle/software/rra-c-util/>.
+ * which can be found at <https://www.eyrie.org/~eagle/software/rra-c-util/>.
  *
  * Written by Russ Allbery <eagle@eyrie.org>
  *
@@ -201,6 +201,22 @@ extern size_t strlcat(char *, const char *, size_t);
 #if !HAVE_DECL_STRLCPY
 extern size_t strlcpy(char *, const char *, size_t);
 #endif
+#if !HAVE_GETPAGESIZE
+extern int getpagesize(void);
+#endif
+#if !HAVE_STRCASECMP
+extern int strcasecmp(const char *, const char *);
+extern int strncasecmp(const char *, const char *, size_t);
+#endif
+#if !HAVE_STRSPN
+extern size_t strspn(const char *, const char *);
+#endif
+#if !HAVE_STRTOK
+extern char * strtok(char *, const char *);
+#endif
+#if !HAVE_MEMCMP
+extern int memcmp(const void *, const void *, size_t);
+#endif
 
 END_DECLS
 
