@@ -1,4 +1,4 @@
-/*  $Id: innconf.h 9752 2014-12-01 20:22:57Z iulius $
+/*  $Id: innconf.h 10064 2016-09-04 12:55:40Z iulius $
 **
 **  inn.conf parser interface.
 **
@@ -122,14 +122,14 @@ struct innconf {
     unsigned long backoffpostslow; /* Lower time limit for slow posting */
     unsigned long backofftrigger;  /* Number of postings before triggered */
 
-    /* Reading and posting -- SSL and TLS support */
+    /* Reading and posting -- TLS/SSL support */
     /* Do not test HAVE_OPENSSL.  This relieves customers of /usr/include/inn
-     * from the need to guess whether INN was built with SSL/TLS support in
+     * from the need to guess whether INN was built with TLS/SSL support in
      * order to get a header that matches the installed libraries.
      */
     char *tlscafile;            /* Path to a certificate authority file */
     char *tlscapath;            /* Path to a directory of CA certificates */
-    char *tlscertfile;          /* Path to the SSL certificate to use */
+    char *tlscertfile;          /* Path to the TLS/SSL certificate to use */
     char *tlskeyfile;           /* Path to the key for the certificate */
     char *tlsciphers;           /* OpenSSL-style cipher string */
     bool tlscompression;        /* Turn TLS compression on/off */
