@@ -1,4 +1,4 @@
-/*  $Id: setproctitle.h 8302 2009-01-29 19:46:28Z iulius $
+/*  $Id: setproctitle.h 9700 2014-09-21 09:15:25Z iulius $
 **
 **  Set things up for setproctitle portably.
 **
@@ -11,9 +11,11 @@
 #define PORTABLE_SETPROCTITLE_H 1
 
 #include "config.h"
+#include "portable/macros.h"
 
 #if !HAVE_SETPROCTITLE || !HAVE_DECL_SETPROCTITLE
-void setproctitle(const char *format, ...);
+void setproctitle(const char *format, ...)
+    __attribute__((__format__(printf, 1, 2)));
 #endif
 
 #if HAVE_SETPROCTITLE || HAVE_PSTAT
