@@ -1,4 +1,4 @@
-/*  $Id: python.c 9364 2011-08-21 23:23:26Z eagle $
+/*  $Id: python.c 9581 2013-12-09 20:07:03Z iulius $
 **
 **  Embed Python in the style of innd's Perl stuff.
 **
@@ -196,9 +196,7 @@ PYmidfilter(char *messageID, int msglen)
 **  Tell the external module about innd's state.
 */
 void
-PYmode(Mode, NewMode, reason)
-    OPERATINGMODE Mode, NewMode;
-    char *reason;
+PYmode(OPERATINGMODE Mode, OPERATINGMODE NewMode, char *reason)
 {
     PyObject	*result;
     char	oldmode[10], newmode[10];
@@ -446,7 +444,6 @@ PY_syslog(PyObject *self UNUSED, PyObject *args)
 
     /* Assign syslog priority by abbreviated names. */
     switch (*loglevel) {
-    default:		priority = LOG_NOTICE ;
     case 'd': case 'D': priority = LOG_DEBUG ;		break;
     case 'i': case 'I': priority = LOG_INFO ;		break;
     case 'n': case 'N': priority = LOG_NOTICE ;		break;
@@ -454,6 +451,7 @@ PY_syslog(PyObject *self UNUSED, PyObject *args)
     case 'e': case 'E': priority = LOG_ERR ;		break;
     case 'c': case 'C': priority = LOG_CRIT ;		break;
     case 'a': case 'A': priority = LOG_ALERT ;		break;
+    default:            priority = LOG_NOTICE ;
     }
 
     /* Log the message. */
