@@ -1,4 +1,4 @@
-/*  $Id: rc.c 9897 2015-06-14 10:10:37Z iulius $
+/*  $Id: rc.c 10012 2016-05-05 12:41:10Z iulius $
 **
 **  Routines for the remote connect channel.  Create an Internet stream
 **  socket that processes connect to.  If the incoming site is not one of
@@ -694,7 +694,7 @@ RCreaddata(int *num, FILE *F, bool *toolong)
   if (*p == '"') { /* double quoted string ? */
     p++;
     do {
-      for (t = p; (*t != '"' || (*t == '"' && *(t - 1) == '\\')) &&
+      for (t = p; (*t != '"' || *(t - 1) == '\\') &&
 	     *t != '\0'; t++);
       if (*t == '\0') {
 	*t++ = '\n';
@@ -1513,7 +1513,7 @@ RCwritelist(char *filename)
         if (*p == '/')
 	   q = p + 1;
 
-    fprintf (F, "##  $Id: rc.c 9897 2015-06-14 10:10:37Z iulius $\n");
+    fprintf (F, "##  $Id: rc.c 10012 2016-05-05 12:41:10Z iulius $\n");
     fprintf (F, "##\n");
     fprintf (F, "##  %s -- Configuration of incoming news feeds\n", q);
     free(r);
