@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.5.  */
+/* A Bison parser, made by GNU Bison 3.0.2.  */
 
 /* Bison interface for Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
-   
+
+   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,33 +26,41 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+#ifndef YY_YY_Y_TAB_H_INCLUDED
+# define YY_YY_Y_TAB_H_INCLUDED
+/* Debug traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+#if YYDEBUG
+extern int yydebug;
+#endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     PEER = 258,
-     GROUP = 259,
-     IVAL = 260,
-     RVAL = 261,
-     NAME = 262,
-     XSTRING = 263,
-     SCOPE = 264,
-     COLON = 265,
-     LBRACE = 266,
-     RBRACE = 267,
-     TRUEBVAL = 268,
-     FALSEBVAL = 269,
-     CHAR = 270,
-     WORD = 271,
-     IP_ADDRESS = 272
-   };
+  enum yytokentype
+  {
+    PEER = 258,
+    GROUP = 259,
+    IVAL = 260,
+    RVAL = 261,
+    NAME = 262,
+    XSTRING = 263,
+    SCOPE = 264,
+    COLON = 265,
+    LBRACE = 266,
+    RBRACE = 267,
+    TRUEBVAL = 268,
+    FALSEBVAL = 269,
+    CHAR = 270,
+    WORD = 271,
+    IP_ADDRESS = 272
+  };
 #endif
 /* Tokens.  */
 #define PEER 258
@@ -71,15 +79,12 @@
 #define WORD 271
 #define IP_ADDRESS 272
 
-
-
-
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
+typedef union YYSTYPE YYSTYPE;
+union YYSTYPE
 {
-
-/* Line 2068 of yacc.c  */
-#line 657 "configfile.y"
+#line 657 "configfile.y" /* yacc.c:1909  */
 
     scope *scp ;
     value *val ;
@@ -89,16 +94,15 @@ typedef union YYSTYPE
     char *string ;
     char chr ;
 
-
-
-/* Line 2068 of yacc.c  */
-#line 96 "y.tab.h"
-} YYSTYPE;
+#line 98 "y.tab.h" /* yacc.c:1909  */
+};
 # define YYSTYPE_IS_TRIVIAL 1
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+
 extern YYSTYPE yylval;
 
+int yyparse (void);
 
+#endif /* !YY_YY_Y_TAB_H_INCLUDED  */
