@@ -1,4 +1,4 @@
-/*  $Id: innlistener.c 9275 2011-07-17 19:09:26Z iulius $
+/*  $Id: innlistener.c 10009 2016-05-05 12:39:19Z iulius $
 **
 **  The implementation of the innfeed InnListener class.
 **
@@ -128,7 +128,7 @@ void gPrintListenerInfo (FILE *fp, unsigned int indentAmt)
     indent [i] = ' ' ;
   indent [i] = '\0' ;
 
-  fprintf (fp,"%sGlobal InnListener list : %p (count %d) {\n",
+  fprintf (fp,"%sGlobal InnListener list : %p (count %u) {\n",
            indent,(void *) listenerList,listenerCount) ;
   for (p = listenerList ; p != NULL ; p = p->next)
     printListenerInfo (p,fp,indentAmt + INDENT_INCR) ;
