@@ -1,4 +1,4 @@
-/*  $Id: misc.c 9911 2015-07-04 21:32:56Z iulius $
+/*  $Id: misc.c 10040 2016-07-31 20:01:43Z iulius $
 **
 **  Helper routines for the innfeed program.
 **
@@ -593,10 +593,8 @@ char* timeToString(time_t t, char* buffer, size_t size)
 {
   static const char defaultFormat[] = "%a %b %d %H:%M:%S %Y" ;
   const struct tm *const tm = localtime(&t);
-#pragma GCC diagnostic ignored "-Wformat-nonliteral"
   strftime (buffer, size,
     timeToStringFormat == 0 ? defaultFormat : timeToStringFormat, tm);
-#pragma GCC diagnostic warning "-Wformat-nonliteral"
   return buffer;
 }
 
