@@ -1,4 +1,4 @@
-/*  $Id: misc.h 6648 2004-01-25 20:07:11Z rra $
+/*  $Id: misc.h 9913 2015-07-07 16:31:52Z iulius $
 **
 **  Miscellaneous utility functions for innfeed.
 **
@@ -9,6 +9,7 @@
 #define misc_h__
 
 #include "config.h"
+#include "portable/macros.h"
 
 #include <stdarg.h>
 #include <sys/types.h>
@@ -42,11 +43,15 @@ typedef void (*EndpWorkCbk) (EndPoint ep, void *data) ;
 /* debugging information */
 extern unsigned int loggingLevel ;     /* if 0 then d_printf is a no-op */
 
+/* used by timeToString with strftime(3) */
+extern char *timeToStringFormat ;
+
 /* the current count of file desccriptors */
 extern unsigned int openfds ;
 
 /* if level <= loggingLevel then print */
-void d_printf (unsigned int level, const char *fmt, ...) __attribute__ ((__format__ (printf, 2, 3)));
+void d_printf (unsigned int level, const char *fmt, ...)
+    __attribute__((__format__ (printf, 2, 3)));
 
 /* for the gethostbyname() error code */
 const char *host_err_str (void) ;
@@ -65,17 +70,19 @@ char *findNonBlankString (char *ptr, char **tail) ;
 
 /* if fp is not NULL then print to it, otherwise syslog at the level. */
 void logOrPrint (int level, FILE *fp, const char *fmt, ...)
-  __attribute__ ((__format__ (printf, 3, 4)));
+    __attribute__((__format__(printf, 3, 4)));
 
 /* Error handling functions for use with warn and die. */
-void error_log_stderr_date(int len, const char *fmt, va_list args, int err);
+void error_log_stderr_date(int len, const char *fmt, va_list args, int err)
+    __attribute__((__format__(printf, 2, 0)));
 
 /* Do cleanup and then abort, for use with die. */
-int dump_core(void);
+void dump_core(void)
+    __attribute__ ((noreturn));
 
 /* Alternate die that doesn't invoke an error handler. */
 void logAndExit (int exitVal, const char *fmt, ...)
-  __attribute__ ((__format__ (printf, 2, 3)));
+    __attribute__((noreturn, __format__(printf, 2, 3)));
 
 /* return true of the file exists and is a regular file */
 bool fileExistsP (const char *filename) ;
@@ -114,12 +121,12 @@ bool isOlder (const char *file1, const char *file2) ;
 /* converts val into a printable string */
 const char *boolToString (bool val) ;
 
+/* strftime with "%a %b %d %H:%M:%S %Y" (like ctime without linefeed) */
+char* timeToString (time_t time, char* buffer, size_t size) ;
+
 /* memory leak checker helper. */
 void addPointerFreedOnExit (char *pointerToFree) ;
 
-/* splice direcotory and fname together and return free'able string */
-char *buildFilename (const char *directory, const char *fname) ;
-
 /* string the file opened by FP to the give SIZE. The NEWNAME is the name
    of the file to have after truncation. FP will be reopened for writing on
    the new file and will be positioned at the end */
