@@ -1,4 +1,4 @@
-/* $Id: getnameinfo.c 9759 2014-12-04 20:11:38Z iulius $
+/* $Id: getnameinfo.c 10105 2016-11-04 22:42:26Z iulius $
  *
  * Replacement for a missing getnameinfo.
  *
@@ -15,7 +15,7 @@
  * support should already support getnameinfo natively.
  *
  * The canonical version of this file is maintained in the rra-c-util package,
- * which can be found at <http://www.eyrie.org/~eagle/software/rra-c-util/>.
+ * which can be found at <https://www.eyrie.org/~eagle/software/rra-c-util/>.
  *
  * Written by Russ Allbery <eagle@eyrie.org>
  *
@@ -154,7 +154,7 @@ lookup_service(unsigned short port, char *service, socklen_t servicelen,
 
     /* Just convert the port number to ASCII. */
     status = snprintf(service, servicelen, "%hu", port);
-    if (status < 0 || (socklen_t) status > servicelen)
+    if (status < 0 || (socklen_t) status >= servicelen)
         return EAI_OVERFLOW;
     return 0;
 }
