@@ -1,4 +1,4 @@
-/* $Id: inet_ntop.c 9759 2014-12-04 20:11:38Z iulius $
+/* $Id: inet_ntop.c 10105 2016-11-04 22:42:26Z iulius $
  *
  * Replacement for a missing inet_ntop.
  *
@@ -9,7 +9,7 @@
  * host supports IPv6.
  *
  * The canonical version of this file is maintained in the rra-c-util package,
- * which can be found at <http://www.eyrie.org/~eagle/software/rra-c-util/>.
+ * which can be found at <https://www.eyrie.org/~eagle/software/rra-c-util/>.
  *
  * Written by Russ Allbery <eagle@eyrie.org>
  *
@@ -68,7 +68,7 @@ inet_ntop(int af, const void *src, char *dst, socklen_t size)
                       (unsigned int) (p[1] & 0xff),
                       (unsigned int) (p[2] & 0xff),
                       (unsigned int) (p[3] & 0xff));
-    if (status < 0)
+    if (status < 0 || (size_t) status >= (size_t) size)
         return NULL;
     return dst;
 }
