@@ -1,4 +1,4 @@
-/*  $Id: innconf.c 9922 2015-07-14 16:43:55Z iulius $
+/*  $Id: innconf.c 10064 2016-09-04 12:55:40Z iulius $
 **
 **  Manage the global innconf struct.
 **
@@ -233,7 +233,7 @@ const struct config config_table[] = {
     { K(tlscertfile),             STRING  (NULL) },
     { K(tlskeyfile),              STRING  (NULL) },
     { K(tlsciphers),              STRING  (NULL) },
-    { K(tlscompression),          BOOL    (true) },
+    { K(tlscompression),          BOOL   (false) },
     { K(tlseccurve),              STRING  (NULL) },
     { K(tlspreferserverciphers),  BOOL    (true) },
     { K(tlsprotocols),            LIST    (NULL) },
@@ -378,7 +378,7 @@ innconf_set_defaults(void)
     if (innconf->extraoverviewhidden == NULL)
         innconf->extraoverviewhidden = vector_new();
 
-    /* Defaults used only if TLS (SSL) is supported. */
+    /* Defaults used only if TLS/SSL is supported. */
 #ifdef HAVE_OPENSSL
     if (innconf->tlscapath == NULL)
         innconf->tlscapath = xstrdup(innconf->pathetc);
