@@ -1,9 +1,9 @@
-/*  $Id: perl.c 8561 2009-08-14 18:32:41Z iulius $
+/*  $Id: perl.c 9930 2015-08-10 11:51:03Z iulius $
 **
 **  Embedded Perl support for INN.
 **
 **  Originally written by Christophe Wolfhugel <wolf@pasteur.fr> (although
-**  he wouldn't recongize it any more, so don't blame him) and modified,
+**  he wouldn't recognize it any more, so don't blame him) and modified,
 **  expanded, and tweaked by James Brister, Dave Hayes, and Russ Allbery
 **  among others.
 **
@@ -66,6 +66,7 @@ PerlFilter(bool value)
 {
     dSP;
     char *argv[] = { NULL };
+    SV *errsv;
 
     if (value == PerlFilterActive)
         return true;
@@ -75,12 +76,16 @@ PerlFilter(bool value)
         if (perl_get_cv("filter_end", false) != NULL) {
             ENTER;
             SAVETMPS;
+            /* No need for PUSHMARK(SP) with call_argv(). */
             perl_call_argv("filter_end", G_EVAL | G_DISCARD | G_NOARGS, argv);
-            if (SvTRUE(ERRSV)) {
+            SPAGAIN;
+            errsv = ERRSV;
+            if (SvTRUE(errsv)) {
                 syslog (L_ERROR, "SERVER perl function filter_end died: %s",
-                        SvPV(ERRSV, PL_na));
+                        SvPV(errsv, PL_na));
                 (void) POPs;
             }
+            PUTBACK;
             FREETMPS;
             LEAVE;
         }
@@ -126,36 +131,51 @@ void PERLsetup (char *startupfile, char *filterfile, const char *function)
 #endif
         perl_parse(PerlCode, xs_init, argc, argv, env) ;
     }
-    
+
     if (startupfile != NULL && filterfile != NULL) {
         char *evalfile = NULL;
+        bool failure;
+        SV *errsv;
         dSP;
-    
-        ENTER ;
-        SAVETMPS ;
 
-        /* The Perl expression which will be evaluated. */   
+        ENTER;
+        SAVETMPS;
+        PUSHMARK(SP);
+        PUTBACK;
+
+        /* The Perl expression which will be evaluated. */
         xasprintf(&evalfile, "do '%s'", startupfile);
 
         PerlSilence();
         perl_eval_pv(evalfile, TRUE);
         PerlUnSilence();
-        
-        SPAGAIN ;
-        
-        if (SvTRUE(ERRSV))     /* check $@ */ {
+
+        SPAGAIN;
+
+        free(evalfile);
+        evalfile = NULL;
+
+        /* Check $@. */
+        errsv = ERRSV;
+        if (SvTRUE(errsv)) {
+            failure = true;
             syslog(L_ERROR,"SERVER perl loading %s failed: %s",
-		   startupfile, SvPV(ERRSV, PL_na)) ;
-            PerlFilter (false) ;
-    
+                   startupfile, SvPV(errsv, PL_na));
         } else {
-            PERLreadfilter (filterfile,function) ;
+            failure = false;
         }
 
-        FREETMPS ;
-        LEAVE ;
+        PUTBACK;
+        FREETMPS;
+        LEAVE;
+
+        if (failure) {
+            PerlFilter (false);
+        } else {
+            PERLreadfilter (filterfile, function);
+        }
     } else {
-        PERLreadfilter (filterfile,function) ;
+        PERLreadfilter (filterfile, function);
     }
 }
 
@@ -167,23 +187,40 @@ void PERLsetup (char *startupfile, char *filterfile, const char *function)
    function there. */
 int PERLreadfilter(char *filterfile, const char *function)
 {
-    dSP ;
+    dSP;
     char *argv[] = { NULL };
     char *evalfile = NULL;
+    bool failure;
+    SV *errsv;
 
-    ENTER ;
-    SAVETMPS ;
-
-    if (perl_get_cv("filter_before_reload", false) != NULL)    {
+    if (perl_get_cv("filter_before_reload", false) != NULL) {
+        ENTER;
+        SAVETMPS;
+        /* No need for PUSHMARK(SP) with call_argv(). */
         perl_call_argv("filter_before_reload", G_EVAL|G_DISCARD|G_NOARGS, argv);
-        if (SvTRUE(ERRSV))     /* check $@ */ {
+        SPAGAIN;
+        /* Check $@. */
+        errsv = ERRSV;
+        if (SvTRUE(errsv)) {
+            failure = true;
             syslog (L_ERROR,"SERVER perl function filter_before_reload died: %s",
-                    SvPV(ERRSV, PL_na)) ;
-            (void)POPs ;
-            PerlFilter (false) ;
+                    SvPV(errsv, PL_na));
+            (void)POPs;
+        } else {
+            failure = false;
         }
+        PUTBACK;
+        FREETMPS;
+        LEAVE;
+        if (failure)
+            PerlFilter (false);
     }
 
+    ENTER;
+    SAVETMPS;
+    PUSHMARK(SP);
+    PUTBACK;
+
     /* The Perl expression which will be evaluated. */
     xasprintf(&evalfile, "do '%s'", filterfile);
 
@@ -191,34 +228,76 @@ int PERLreadfilter(char *filterfile, const char *function)
     perl_eval_pv(evalfile, TRUE);
     PerlUnSilence();
 
+    SPAGAIN;
+
     free(evalfile);
     evalfile = NULL;
 
-    if (SvTRUE(ERRSV))     /* check $@ */ {
+    /* Check $@. */
+    errsv = ERRSV;
+    if (SvTRUE(errsv)) {
+        failure = true;
         syslog (L_ERROR,"SERVER perl loading %s failed: %s",
-                filterfile, SvPV(ERRSV, PL_na)) ;
-        PerlFilter (false) ;
-        
+                filterfile, SvPV(errsv, PL_na));
+    } else {
+        failure = false;
+    }
+    PUTBACK;
+    FREETMPS;
+    LEAVE;
+    if (failure) {
+        PerlFilter (false);
+
         /* If the reload failed we don't want the old definition hanging
            around. */
+
+        ENTER;
+        SAVETMPS;
+        PUSHMARK(SP);
+        PUTBACK;
+
         xasprintf(&evalfile, "undef &%s", function);
         perl_eval_pv(evalfile, TRUE);
 
-        if (SvTRUE(ERRSV))     /* check $@ */ {
+        SPAGAIN;
+
+        free(evalfile);
+        evalfile = NULL;
+
+        /* Check $@. */
+        errsv = ERRSV;
+        if (SvTRUE(errsv)) {
             syslog (L_ERROR,"SERVER perl undef &%s failed: %s",
-                    function, SvPV(ERRSV, PL_na)) ;
+                    function, SvPV(errsv, PL_na)) ;
         }
+        PUTBACK;
+        FREETMPS;
+        LEAVE;
     } else if ((perl_filter_cv = perl_get_cv(function, false)) == NULL) {
-        PerlFilter (false) ;
+        PerlFilter (false);
     }
 
     if (perl_get_cv("filter_after_reload", false) != NULL) {
+        ENTER;
+        SAVETMPS;
+        /* No need for PUSHMARK(SP) with call_argv(). */
         perl_call_argv("filter_after_reload", G_EVAL|G_DISCARD|G_NOARGS, argv);
-        if (SvTRUE(ERRSV))     /* check $@ */ {
+        SPAGAIN;
+        /* Check $@. */
+        errsv = ERRSV;
+        if (SvTRUE(errsv)) {
+            failure = true;
             syslog (L_ERROR,"SERVER perl function filter_after_reload died: %s",
-                    SvPV(ERRSV, PL_na)) ;
-            (void)POPs ;
-            PerlFilter (false) ;
+                    SvPV(errsv, PL_na));
+            (void)POPs;
+        } else {
+            failure = false;
+        }
+        PUTBACK;
+        FREETMPS;
+        LEAVE;
+        if (failure) {
+            PerlFilter (false);
         }
     }
 
@@ -237,9 +316,6 @@ int PERLreadfilter(char *filterfile, const char *function)
         }
     }
 
-    FREETMPS ;
-    LEAVE ;
-
     return (perl_filter_cv != NULL) ;
 }
 
@@ -296,7 +372,7 @@ void PerlSilence(void)
     savestdout = 0;
     return;
   }
-    
+
   if (dup2(newfd,2) < 0) {
     syslog(L_ERROR,"SERVER perl silence cant redirect stderr: %m");
     savestderr = 0;
@@ -352,7 +428,6 @@ XS(XS_INN_syslog)
     logmsg = (const char *) SvPV(ST(1), PL_na);
 
     switch (*loglevel) {
-        default:                priority = LOG_NOTICE;
         case 'a': case 'A':     priority = LOG_ALERT;           break;
         case 'c': case 'C':     priority = LOG_CRIT;            break;
         case 'e': case 'E':     priority = LOG_ERR;             break;
@@ -360,6 +435,7 @@ XS(XS_INN_syslog)
         case 'n': case 'N':     priority = LOG_NOTICE;          break;
         case 'i': case 'I':     priority = LOG_INFO;            break;
         case 'd': case 'D':     priority = LOG_DEBUG;           break;
+        default:                priority = LOG_NOTICE;
     }
     syslog(priority, "filter: %s", logmsg);
     XSRETURN_UNDEF;
