@@ -1,4 +1,4 @@
-/*  $Id: radix32.c,v 1.5 2003/01/13 06:44:23 rra Exp $
+/*  $Id: radix32.c 7585 2006-11-21 09:37:51Z eagle $
 **
 **  Radix-32 strings divide a number into five-bit nibbles and use the
 **  alphabet 0..9a..v to represent 0..32.
@@ -8,7 +8,7 @@
 #include "clibrary.h"
 #include <time.h>
 
-#include "libinn.h"
+#include "inn/libinn.h"
 
 
 static char	ALPHABET[] =
