@@ -1,28 +1,31 @@
-/*  $Revision: 1.3 $
+/*  $Id: readin.c 7585 2006-11-21 09:37:51Z eagle $
 **
 */
-#include <stdio.h>
-#include <sys/types.h>
-#include "configdata.h"
+
+#include "config.h"
 #include "clibrary.h"
 #include <errno.h>
-#include <sys/stat.h>
 #include <fcntl.h>
-#include "libinn.h"
-#include "macros.h"
+#include <sys/stat.h>
+
+#include "inn/libinn.h"
 
 
 /*
-**  Read a big amount, looping until it is all done.  Return TRUE if
+**  Read a big amount, looping until it is all done.  Return true if
 **  successful.
 */
-int xread(int fd, char *p, OFFSET_T i)
+int xread(int fd, char *p, off_t i)
 {
     int	                count;
 
-    for ( ; i; p += count, i -= count)
-	if ((count = read(fd, p, (SIZE_T)i)) <= 0)
-	    return -1;
+    for ( ; i; p += count, i -= count) {
+        do {
+            count = read(fd, p, i);
+        } while (count == -1 && errno == EINTR);
+        if (count <= 0)
+            return -1;
+    }
     return 0;
 }
 
@@ -42,17 +45,17 @@ char *ReadInDescriptor(int fd, struct stat *Sbp)
     /* Get the size, and enough memory. */
     if (fstat(fd, Sbp) < 0) {
 	oerrno = errno;
-	(void)close(fd);
+	close(fd);
 	errno = oerrno;
 	return NULL;
     }
-    p = NEW(char, Sbp->st_size + 1);
+    p = xmalloc(Sbp->st_size + 1);
 
     /* Slurp, slurp. */
-    if (xread(fd, p, (OFFSET_T)(Sbp->st_size)) < 0) {
+    if (xread(fd, p, Sbp->st_size) < 0) {
 	oerrno = errno;
-	DISPOSE(p);
-	(void)close(fd);
+	free(p);
+	close(fd);
 	errno = oerrno;
 	return NULL;
     }
@@ -76,6 +79,6 @@ char *ReadInFile(const char *name, struct stat *Sbp)
 	return NULL;
 
     p = ReadInDescriptor(fd, Sbp);
-    (void)close(fd);
+    close(fd);
     return p;
 }
