@@ -1,14 +1,17 @@
-/*  $Id: resource.c 6135 2003-01-19 01:15:40Z rra $
+/*  $Id: resource.c 9754 2014-12-01 21:08:28Z iulius $
 **
 */
 
 #include "config.h"
 #include "clibrary.h"
-#include "libinn.h"
+#include "inn/libinn.h"
 
 #ifdef HAVE_GETRUSAGE
 
-#include <sys/time.h>
+#ifdef HAVE_SYS_TIME_H
+# include <sys/time.h>
+#endif
+#include <time.h>
 #include <sys/resource.h>
 
 #define TIMEVALasDOUBLE(t)	\
