@@ -1,4 +1,4 @@
-/*  $Id: commands.c 9850 2015-05-03 15:25:53Z iulius $
+/*  $Id: commands.c 9978 2015-12-11 20:39:56Z iulius $
 **
 **  Miscellaneous commands.
 */
@@ -14,8 +14,8 @@
 #include "inn/version.h"
 #include "tls.h"
 
-#ifdef HAVE_OPENSSL
-extern bool nnrpd_starttls_done;
+#if defined(HAVE_OPENSSL)
+extern bool encryption_layer_on;
 #endif /* HAVE_OPENSSL */
 
 typedef struct {
@@ -264,6 +264,14 @@ CMDauthinfo(int ac, char *av[])
     char        errorstr[BIG_BUFFER];
     int         code;
 
+#if defined(HAVE_ZLIB)
+    /* If a compression layer is active, AUTHINFO is not possible. */
+    if (compression_layer_on && !tls_compression_on) {
+        Reply("%d Already using a compression layer\r\n", NNTP_ERR_ACCESS);
+        return;
+    }
+#endif
+
     if (strcasecmp(av[1], "GENERIC") == 0) {
 	char *logrec = Glom(av);
 
@@ -326,7 +334,7 @@ CMDauthinfo(int ac, char *av[])
 #ifdef HAVE_OPENSSL
             /* Check whether STARTTLS must be used before trying to authenticate. */
             if (PERMcanauthenticate && !PERMcanauthenticatewithoutSSL
-                && !nnrpd_starttls_done) {
+                && !encryption_layer_on) {
                 Reply("%d Encryption required\r\n", NNTP_FAIL_PRIVACY_NEEDED);
                 return;
             }
@@ -355,7 +363,7 @@ CMDauthinfo(int ac, char *av[])
 #ifdef HAVE_OPENSSL
         /* Check whether STARTTLS must be used before trying to authenticate. */
         if (PERMcanauthenticate && !PERMcanauthenticatewithoutSSL
-            && !nnrpd_starttls_done) {
+            && !encryption_layer_on) {
              Reply("%d Encryption required\r\n", NNTP_FAIL_PRIVACY_NEEDED);
              return;
         }
