@@ -1,4 +1,4 @@
-/*  $Id: misc.c 9563 2013-11-10 13:13:34Z iulius $
+/*  $Id: misc.c 10078 2016-10-08 20:53:39Z iulius $
 **
 **  Miscellaneous support routines.
 */
@@ -18,12 +18,12 @@
 /* Outside the ifdef so that make depend works even ifndef HAVE_OPENSSL. */
 #include "inn/ov.h"
 
-#ifdef HAVE_OPENSSL
+#if defined(HAVE_OPENSSL)
 extern SSL *tls_conn;
 extern int tls_cipher_usebits;
 extern char *tls_peer_CN;
-extern bool nnrpd_starttls_done;
-#endif 
+extern bool encryption_layer_on;
+#endif /* HAVE_OPENSSL */ 
 
 
 /*
@@ -244,14 +244,14 @@ PostRecFilename(char *ip, char *user)
      for (i=0; i<4; i++)
        quads[i] = (unsigned char) (0xff & (addr>>(i*8)));
 
-     snprintf(dirbuff, sizeof(dirbuff), "%s/%03d%03d/%03d",
+     snprintf(dirbuff, sizeof(dirbuff), "%s/%03u%03u/%03u",
          postrec_dir, quads[3], quads[2], quads[1]);
      if (!MakeDirectory(dirbuff,true)) {
        syslog(L_ERROR, "%s Unable to create postrec directories '%s': %s",
                Client.host, dirbuff, strerror(errno));
        return NULL;
      }
-     snprintf(buff, sizeof(buff), "%s/%03d", dirbuff, quads[0]);
+     snprintf(buff, sizeof(buff), "%s/%03u", dirbuff, quads[0]);
      return(buff);
 }
 
@@ -275,7 +275,7 @@ LockPostRec(char *path)
     fd = open(lockname, O_WRONLY|O_EXCL|O_CREAT, 0600);
     if (fd >= 0) {
       /* We got the lock! */
-      snprintf(temp, sizeof(temp), "pid:%ld\n", (unsigned long) getpid());
+      snprintf(temp, sizeof(temp), "pid:%lu\n", (unsigned long) getpid());
       write(fd, temp, strlen(temp));
       close(fd);
       return(1);
@@ -449,7 +449,91 @@ RateLimit(long *sleeptime, char *path)
      return 1;
 }
 
-#ifdef HAVE_OPENSSL
+#if defined(HAVE_SASL) || defined(HAVE_ZLIB)
+/*
+**  Check if the argument has a valid syntax.
+**
+**  Currently used for both SASL mechanisms (RFC 4643) and compression
+**  algorithms.
+**
+**    algorithm = 1*20alg-char
+**    alg-char = UPPER / DIGIT / "-" / "_"
+*/
+bool
+IsValidAlgorithm(const char *string)
+{
+    size_t len = 0;
+    const unsigned char *p;
+
+    /* Not NULL. */
+    if (string == NULL) {
+        return false;
+    }
+
+    p = (const unsigned char *) string;
+
+    for (; *p != '\0'; p++) {
+        len++;
+
+        if (!isupper((unsigned char) *p) && !isdigit((unsigned char) *p)
+            && *p != '-' && *p != '_') {
+            return false;
+        }
+    }
+
+    if (len > 0 && len < 21) {
+        return true;
+    } else {
+        return false;
+    }
+}
+#endif /* HAVE_SASL || HAVE_ZLIB */
+
+#if defined(HAVE_ZLIB)
+/*
+**  The COMPRESS command.
+*/
+void
+CMDcompress(int ac, char *av[])
+{
+    bool result;
+
+    /* Check the argument. */
+    if (ac > 1) {
+        if (!IsValidAlgorithm(av[1])) {
+            Reply("%d Syntax error in compression algorithm name\r\n",
+                  NNTP_ERR_SYNTAX);
+            return;
+        }
+        if (strcasecmp(av[1], "DEFLATE") != 0) {
+            Reply("%d Only the DEFLATE compression algorithm is supported\r\n",
+                  NNTP_ERR_UNAVAILABLE);
+            return;
+        }
+    }
+
+    if (compression_layer_on) {
+        Reply("%d Already using a compression layer\r\n", NNTP_ERR_ACCESS);
+        return;
+    }
+
+    result = zlib_init();
+
+    if (!result) {
+        Reply("%d Impossible to activate compression\r\n", NNTP_FAIL_ACTION);
+        return;
+    }
+
+    Reply("%d Compression now active; enjoy the speed!\r\n", NNTP_OK_COMPRESS);
+
+    /* Flush any pending output, before enabling compression. */
+    fflush(stdout);
+
+    compression_layer_on = true;
+}
+#endif /* HAVE_ZLIB */
+
+#if defined(HAVE_OPENSSL)
 /*
 **  The STARTTLS command.  RFC 4642.
 */
@@ -459,11 +543,19 @@ CMDstarttls(int ac UNUSED, char *av[] UNUSED)
     int result;
     bool boolval;
 
-    if (nnrpd_starttls_done) {
-        Reply("%d Already using an active TLS layer\r\n", NNTP_ERR_ACCESS);
+    if (encryption_layer_on) {
+        Reply("%d Already using a security layer\r\n", NNTP_ERR_ACCESS);
         return;
     }
 
+# if defined(HAVE_ZLIB)
+    /* If a compression layer is active, STARTTLS is not possible. */
+    if (compression_layer_on) {
+        Reply("%d Already using a compression layer\r\n", NNTP_ERR_ACCESS);
+        return;
+    }
+# endif /* HAVE_ZLIB */
+
     /* If the client is already authenticated, STARTTLS is not possible. */
     if (PERMauthorized && !PERMneedauth && !PERMcanauthenticate) {
         Reply("%d Already authenticated without the use of a security layer\r\n",
@@ -478,6 +570,35 @@ CMDstarttls(int ac UNUSED, char *av[] UNUSED)
         return;
     }
 
+    /* Close out any existing article, report group stats.
+     * RFC 4642 requires the reset of any knowledge about the client. */
+    if (GRPcur) {
+        ARTclose();
+        GRPreport();
+        OVctl(OVCACHEFREE, &boolval);
+        free(GRPcur);
+        GRPcur = NULL;
+        if (ARTcount) {
+            syslog(L_NOTICE, "%s exit for STARTTLS articles %ld groups %ld",
+                   Client.host, ARTcount, GRPcount);
+        }
+        GRPcount = 0;
+        PERMgroupmadeinvalid = false;
+    }
+
+    /* We can now assume a secure connection will be negotiated because
+     * nnrpd will exit if STARTTLS fails.
+     * Check the permissions the client will have after having successfully
+     * negotiated a TLS layer.  (There may be auth blocks requiring the
+     * negotiation of a security layer in readers.conf that match the
+     * connection.)
+     * In case the client would no longer have access to the server, or an
+     * authentication error happens, the connection aborts after a fatal 400
+     * response code sent by PERMgetpermissions(). */
+    encryption_layer_on = true;
+    PERMgetaccess(false);
+    PERMgetpermissions();
+
     Reply("%d Begin TLS negotiation now\r\n", NNTP_CONT_STARTTLS);
     fflush(stdout);
 
@@ -491,7 +612,7 @@ CMDstarttls(int ac UNUSED, char *av[] UNUSED)
         ExitWithStats(1, false);
     }
 
-#ifdef HAVE_SASL
+# if defined(HAVE_SASL)
     /* Tell SASL about the negotiated layer. */
     result = sasl_setprop(sasl_conn, SASL_SSF_EXTERNAL,
                           (sasl_ssf_t *) &tls_cipher_usebits);
@@ -503,24 +624,15 @@ CMDstarttls(int ac UNUSED, char *av[] UNUSED)
     if (result != SASL_OK) {
         syslog(L_NOTICE, "sasl_setprop() failed: CMDstarttls()");
     }
-#endif /* HAVE_SASL */
+# endif /* HAVE_SASL */
 
-    nnrpd_starttls_done = true;
-
-    /* Close out any existing article, report group stats.
-     * RFC 4642 requires the reset of any knowledge about the client. */
-    if (GRPcur) {
-        ARTclose();
-        GRPreport();
-        OVctl(OVCACHEFREE, &boolval);
-        free(GRPcur);
-        GRPcur = NULL;
-        if (ARTcount)
-            syslog(L_NOTICE, "%s exit for STARTTLS articles %ld groups %ld",
-                   Client.host, ARTcount, GRPcount);
-        GRPcount = 0;
-        PERMgroupmadeinvalid = false;
-    }
+# if defined(HAVE_ZLIB) && OPENSSL_VERSION_NUMBER >= 0x00090800fL
+    /* Check whether a compression layer has just been added.
+     * SSL_get_current_compression() is defined in OpenSSL versions >= 0.9.8
+     * final release. */
+    tls_compression_on = (SSL_get_current_compression(tls_conn) != NULL);
+    compression_layer_on = tls_compression_on;
+# endif /* HAVE_ZLIB && OPENSSL >= v0.9.8 */
 
     /* Reset our read buffer so as to prevent plaintext command injection. */
     line_reset(&NNTPline);
