@@ -1,4 +1,4 @@
-/*  $Id: nnrpd.c 9913 2015-07-07 16:31:52Z iulius $
+/*  $Id: nnrpd.c 10063 2016-09-04 12:53:12Z iulius $
 **
 **  NNTP server for readers (NNRP) for InterNetNews.
 **
@@ -13,7 +13,9 @@
 #include "portable/socket.h"
 #include <netdb.h>
 #include <signal.h>
-#include <netinet/tcp.h>
+#if defined(INN_BSDI_HOST)
+# include <netinet/tcp.h>
+#endif
 
 #if HAVE_GETSPNAM
 # include <shadow.h>
@@ -33,9 +35,12 @@
 
 #include "tls.h"
 
-#ifdef HAVE_OPENSSL
+#if defined(HAVE_OPENSSL)
 extern SSL *tls_conn;
-bool nnrpd_starttls_done = false;
+#endif
+
+#if defined(HAVE_OPENSSL) || defined(HAVE_SASL)
+bool encryption_layer_on = false;
 #endif 
 
 
@@ -126,6 +131,10 @@ static CMDENT	CMDtable[] = {
 	CMDfetchhelp },
     {   "CAPABILITIES", CMDcapabilities,false,  1,      2,      true,
         "[keyword]" },
+#if defined(HAVE_ZLIB)
+    {   "COMPRESS",     CMDcompress,    false,  2,      2,      true,
+        "DEFLATE" },
+#endif
     {	"DATE",		CMDdate,	false,	1,	1,      true,
 	NULL },
     {	"GROUP",	CMDgroup,	true,	2,	2,      true,
@@ -254,6 +263,17 @@ ExitWithStats(int x, bool readconf)
     sasl_done();
 #endif /* HAVE_SASL */
 
+#if defined(HAVE_ZLIB)
+    if (compression_layer_on) {
+        inflateEnd(zstream_in);
+        free(zstream_in);
+        free(zbuf_in);
+        deflateEnd(zstream_out);
+        free(zstream_out);
+        free(zbuf_out);
+    }
+#endif /* HAVE_ZLIB */
+
      if (DaemonMode) {
      	shutdown(STDIN_FILENO, 2);
      	shutdown(STDOUT_FILENO, 2);
@@ -369,18 +389,24 @@ CMDcapabilities(int ac, char *av[])
     if ((!PERMauthorized || PERMneedauth || PERMcanauthenticate)) {
         Printf("AUTHINFO");
 
-        /* No arguments if the server does not permit any authentication commands
-         * in its current state. */
-        if (PERMcanauthenticate) {
+        /* No arguments if the server does not permit any authentication
+         * commands in its current state (either a compression layer other
+         * than the one negotiated along with TLS is active, or the user
+         * has no way to authenticate successfully). */
+        if (
+#if defined(HAVE_ZLIB)
+            (!compression_layer_on || tls_compression_on) &&
+#endif /* HAVE_ZLIB */
+            PERMcanauthenticate) {
 #ifdef HAVE_OPENSSL
-            if (PERMcanauthenticatewithoutSSL || nnrpd_starttls_done) {
+            if (PERMcanauthenticatewithoutSSL || encryption_layer_on) {
 #endif
                 /* AUTHINFO USER is advertised only if a TLS layer is active,
                  * if compiled with TLS support. */
                 Printf(" USER");
 #ifdef HAVE_OPENSSL
             } else {
-#ifdef HAVE_SASL
+# ifdef HAVE_SASL
                 /* Remove unsecure PLAIN, LOGIN and EXTERNAL SASL mechanisms,
                  * if compiled with TLS support and a TLS layer is not active. */
                 if (mechlist != NULL) {
@@ -399,7 +425,7 @@ CMDcapabilities(int ac, char *av[])
                         memmove(p, p+9, strlen(p)-8);
                     }
                 }
-#endif /* HAVE_SASL */
+# endif /* HAVE_SASL */
             }
 #endif /* HAVE_OPENSSL */
 #ifdef HAVE_SASL
@@ -412,6 +438,13 @@ CMDcapabilities(int ac, char *av[])
         Printf("\r\n");
     }
 
+#if defined(HAVE_ZLIB)
+    /* A compression layer is not active. */
+    if (!compression_layer_on) {
+        Printf("COMPRESS DEFLATE\r\n");
+    }
+#endif /* HAVE_ZLIB */
+
     if (PERMcanread) {
         Printf("HDR\r\n");
     }
@@ -437,20 +470,31 @@ CMDcapabilities(int ac, char *av[])
 
     Printf("READER\r\n");
 
-#ifdef HAVE_SASL
-    /* Check whether at least one SASL mechanism is available. */
+#if defined(HAVE_SASL)
+    /* Check whether at least one SASL mechanism is available.
+     * The SASL capability has to be advertised, even after authentication,
+     * so that the client can detect a possible active down-negotiation
+     * attack. */
     if (mechlist != NULL && strlen(mechlist) > 2) {
         Printf("SASL%s\r\n", mechlist);
     }
-#endif
+#endif /* HAVE_SASL */
 
-#ifdef HAVE_OPENSSL
-    /* A TLS layer is not active and the client is not already authenticated. */
-    if (!nnrpd_starttls_done
+#if defined(HAVE_OPENSSL)
+    /* A TLS layer is not active, a compression layer is not active,
+     * and the client is not already authenticated. */
+    if (!encryption_layer_on
+# if defined(HAVE_ZLIB)
+        && !compression_layer_on
+# endif /* HAVE_ZLIB */
         && (!PERMauthorized || PERMneedauth || PERMcanauthenticate)) {
         Printf("STARTTLS\r\n");
     }
-#endif
+#endif /* HAVE_OPENSSL */
+
+    if (PERMcanread) {
+        Printf("XPAT\r\n");
+    }
 
     Printf(".\r\n");
 }
@@ -541,7 +585,6 @@ StartConnection(unsigned short port)
     struct sockaddr *sas = (struct sockaddr *) &sss;
     socklen_t length;
     size_t size;
-    int nodelay = 1;
 
     memset(&Client, 0, sizeof(Client));
     strlcpy(Client.host, "?", sizeof(Client.host));
@@ -610,19 +653,25 @@ StartConnection(unsigned short port)
         Client.serverport = network_sockaddr_port(sas);
     }
 
+#if defined(INN_BSDI_HOST)
     /* Setting TCP_NODELAY to nnrpd fixes a problem of slow downloading
-     * of overviews and slow answers on some architectures (like BSD/OS). */
+     * of overviews and slow answers on some architectures (like BSD/OS
+     * where TCP delayed acknowledgements are enabled). */
+    int nodelay = 1;
     setsockopt(STDIN_FILENO, IPPROTO_TCP, TCP_NODELAY, &nodelay, sizeof(nodelay));
+#endif
 
     notice("%s (%s) connect - port %u", Client.host, Client.ip, port);
 
-    PERMgetaccess(NNRPACCESS);
+    PERMgetinitialaccess(NNRPACCESS);
+    PERMgetaccess(true);
     PERMgetpermissions();
 }
 
 
 /*
-**  Write a buffer, via SASL security layer and/or TLS if necessary.
+**  Write a buffer, via compression layer and/or SASL security layer
+**  and/or TLS if necessary.
 */
 void
 write_buffer(const char *buff, ssize_t len)
@@ -631,29 +680,68 @@ write_buffer(const char *buff, ssize_t len)
     ssize_t n;
 
     TMRstart(TMR_NNTPWRITE);
-
     p = buff;
+
+#if defined(HAVE_ZLIB)
+    if (compression_layer_on) {
+        int r;
+
+        zstream_out->next_in = (unsigned char *) p;
+        zstream_out->avail_in = len;
+        zstream_out->next_out = zbuf_out;
+        zstream_out->avail_out = zbuf_out_size;
+
+        do {
+            /* Grow the output buffer if needed. */
+            if (zstream_out->avail_out == 0) {
+                size_t newsize = zbuf_out_size * 2;
+                zbuf_out = xrealloc(zbuf_out, newsize);
+                zstream_out->next_out = zbuf_out + zbuf_out_size;
+                zstream_out->avail_out = zbuf_out_size;
+                zbuf_out_size = newsize;
+            }
+
+            r = deflate(zstream_out,
+                        zstream_flush_needed ? Z_PARTIAL_FLUSH : Z_NO_FLUSH);
+
+            if (!(r == Z_OK || r == Z_BUF_ERROR || r == Z_STREAM_END)) {
+                sysnotice("deflate() failed: %d; %s", r,
+                          zstream_out->msg != NULL ? zstream_out->msg :
+                          "no detail");
+                return;
+            }
+        } while (r == Z_OK && zstream_out->avail_out == 0);
+
+        p = (char *) zbuf_out;
+        len = zbuf_out_size - zstream_out->avail_out;
+        zstream_flush_needed = false;
+    }
+#endif /* HAVE_ZLIB */
+
     while (len > 0) {
 	const char *out;
 	unsigned outlen;
 
-#ifdef HAVE_SASL
-	if (sasl_conn && sasl_ssf) {
+#if defined(HAVE_SASL)
+        if (sasl_conn != NULL && sasl_ssf > 0) {
             int r;
 
-	    /* Can only encode as much as the client can handle at one time. */
-	    n = (len > sasl_maxout) ? sasl_maxout : len;
-	    if ((r = sasl_encode(sasl_conn, p, n, &out, &outlen)) != SASL_OK) {
-		sysnotice("sasl_encode() failed: %s",
-			  sasl_errstring(r, NULL, NULL));
-		return;
-	    }
-	} else
+            /* Can only encode as much as the client can handle at one time. */
+            n = (len > sasl_maxout) ? sasl_maxout : len;
+            if ((r = sasl_encode(sasl_conn, p, n, &out, &outlen)) != SASL_OK) {
+                const char *ed = sasl_errdetail(sasl_conn);
+
+                sysnotice("sasl_encode() failed: %s; %s",
+                          sasl_errstring(r, NULL, NULL),
+                          ed != NULL ? ed : "no detail");
+                return;
+            }
+        } else
 #endif /* HAVE_SASL */
 	{
 	    /* Output the entire unencoded string. */
 	    n = len;
-	    out = buff;
+	    out = p;
 	    outlen = len;
 	}
 
@@ -702,6 +790,10 @@ VPrintf(const char *fmt, va_list args, int dotrace)
     ssize_t len;
 
     len = vsnprintf(buff, sizeof(buff), fmt, args);
+    if (len < 0)
+        len = 0;
+    else if ((size_t)len >= sizeof(buff))
+        len = sizeof(buff) - 1;
     write_buffer(buff, len);
 
     if (dotrace && Tracing) {
@@ -729,6 +821,11 @@ Reply(const char *fmt, ...)
 {
     va_list args;
 
+#if defined(HAVE_ZLIB)
+    /* For single-line responses, immediately flush the output stream. */
+    zstream_flush_needed = true;
+#endif /* HAVE_ZLIB */
+
     va_start(args, fmt);
     VPrintf(fmt, args, 1);
     va_end(args);
@@ -739,6 +836,16 @@ Printf(const char *fmt, ...)
 {
     va_list args;
 
+#if defined(HAVE_ZLIB)
+    /* Last line of a multi-line data block response.
+     * Time to flush the compressed output stream.
+     * Check that only when the compression layer is active. */
+    if (compression_layer_on &&
+        strlen(fmt) == 3 && strcasecmp(fmt, ".\r\n") == 0) {
+        zstream_flush_needed = true;
+    }
+#endif /* HAVE_ZLIB */
+
     va_start(args, fmt);
     VPrintf(fmt, args, 0);
     va_end(args);
@@ -851,7 +958,7 @@ main(int argc, char *argv[])
     char                **v;
     char		*Reject;
     int			timeout;
-    unsigned int	vid=0; 
+    unsigned int	vid=0;
     int 		count=123456789;
     struct		timeval tv;
     unsigned short	ListenPort = NNTP_PORT;
@@ -969,7 +1076,7 @@ main(int argc, char *argv[])
 	    Tracing = true;
 	    break;
 #ifdef HAVE_OPENSSL
-	case 'S':			/* Force SSL negotiation. */
+	case 'S':			/* Force the negotiation of an encryption layer. */
 	    initialSSL = true;
 	    break;
 #endif /* HAVE_OPENSSL */
@@ -1198,10 +1305,18 @@ main(int argc, char *argv[])
     if (initialSSL) {
         tls_init();
         if (tls_start_servertls(0, 1) == -1) {
-            Reply("%d SSL connection failed\r\n", NNTP_FAIL_TERMINATING);
+            Reply("%d Encrypted TLS connection failed\r\n", NNTP_FAIL_TERMINATING);
             ExitWithStats(1, false);
         }
-        nnrpd_starttls_done = true;
+        encryption_layer_on = true;
+
+# if defined(HAVE_ZLIB) && OPENSSL_VERSION_NUMBER >= 0x00090800fL
+        /* Check whether a compression layer has just been added.
+         * SSL_get_current_compression() is defined in OpenSSL versions >= 0.9.8
+         * final release. */
+        tls_compression_on = (SSL_get_current_compression(tls_conn) != NULL);
+        compression_layer_on = tls_compression_on;
+# endif /* HAVE_ZLIB && OPENSSL >= v0.9.8 */
     }
 #endif /* HAVE_OPENSSL */
 
@@ -1264,7 +1379,7 @@ main(int argc, char *argv[])
 	vid = tv.tv_sec ^ tv.tv_usec ^ pid ^ count;
 	len = strlen("innconf->pathlog") + strlen("/tracklogs/log-") + BUFSIZ;
 	LocalLogFileName = xmalloc(len);
-	sprintf(LocalLogFileName, "%s/tracklogs/log-%d", innconf->pathlog, vid);
+	sprintf(LocalLogFileName, "%s/tracklogs/log-%u", innconf->pathlog, vid);
 	if ((locallog = fopen(LocalLogFileName, "w")) == NULL) {
             LocalLogDirName = concatpath(innconf->pathlog, "tracklogs");
 	    MakeDirectory(LocalLogDirName, false);
