@@ -1,7 +1,7 @@
 /*
 ** AUTHINFO SASL functionality.
 **
-** $Id: sasl.c 9259 2011-07-17 18:22:50Z iulius $
+** $Id: sasl.c 10117 2016-11-06 14:23:27Z iulius $
 */
 
 #include "config.h"
@@ -10,18 +10,19 @@
 #include "inn/messages.h"
 #include "nnrpd.h"
 
-/* Outside the ifdef so that make depend works even ifndef HAVE_SSL. */
+/* Outside the ifdef so that make depend works even ifndef HAVE_OPENSSL. */
 #include "inn/ov.h"
+#include "tls.h"
 
-#ifdef HAVE_SSL
+#if defined(HAVE_OPENSSL)
 extern int tls_cipher_usebits;
 extern char *tls_peer_CN;
-extern bool nnrpd_starttls_done;
-#endif /* HAVE_SSL */
+#endif /* HAVE_OPENSSL */
+#if defined(HAVE_OPENSSL) || defined(HAVE_SASL)
+extern bool encryption_layer_on;
+#endif /* HAVE_OPENSSL || HAVE_SASL */
 
 #ifdef HAVE_SASL
-
-#include <sasl/sasl.h>
 sasl_conn_t *sasl_conn = NULL;
 int sasl_ssf = 0;
 int sasl_maxout = NNTP_MAXLEN_COMMAND;
@@ -35,38 +36,6 @@ sasl_callback_t sasl_callbacks[] = {
 #define BASE64_BUF_SIZE 21848   /* Per RFC 4422:  (floor(n/3) + 1) * 4
                                    where n = 16 kB = 16384 bytes. */
 
-
-/*
-**  Check if the argument is a valid mechanism according to RFC 4643:
-**
-**    mechanism = 1*20mech-char
-**    mech-char = UPPER / DIGIT / "-" / "_"
-*/
-static bool
-IsValidMechanism(const char *string)
-{
-    int len = 0;
-    const unsigned char *p;
- 
-    /* Not NULL. */
-    if (string == NULL)
-        return false;
-
-    p = (const unsigned char *) string;
-
-    for (; *p != '\0'; p++) {
-        len++;
-        if (!isalnum((unsigned char) *p) && *p != '-' && *p != '_')
-            return false;
-    }
-
-    if (len > 0 && len < 21)
-        return true;
-    else
-        return false;
-}
-
-
 /*
 **  Create a new SASL server authentication object.
 */
@@ -94,9 +63,9 @@ SASLnewserver(void)
         secprops.max_ssf = 256;
         secprops.maxbufsize = NNTP_MAXLEN_COMMAND;
         sasl_setprop(sasl_conn, SASL_SEC_PROPS, &secprops);
-#ifdef HAVE_SSL
+#ifdef HAVE_OPENSSL
         /* Tell SASL about the negotiated TLS layer. */
-        if (nnrpd_starttls_done) {
+        if (encryption_layer_on) {
             if (sasl_setprop(sasl_conn, SASL_SSF_EXTERNAL,
                              (sasl_ssf_t *) &tls_cipher_usebits) != SASL_OK) {
                 syslog(L_NOTICE, "sasl_setprop() failed:  TLS layer for SASL");
@@ -117,6 +86,7 @@ SASLauth(int ac, char *av[])
     const char *mech;
     const char *clientin = NULL;
     unsigned int clientinlen = 0;
+    size_t tclientinlen = 0;
     const char *serverout = NULL;
     unsigned int serveroutlen;
     char base64[BASE64_BUF_SIZE+1];
@@ -136,8 +106,8 @@ SASLauth(int ac, char *av[])
 
     mech = av[2];
 
-    if (!IsValidMechanism(mech)) {
-        Reply("%d Syntax error in mechanism\r\n", NNTP_ERR_SYNTAX);
+    if (!IsValidAlgorithm(mech)) {
+        Reply("%d Syntax error in mechanism name\r\n", NNTP_ERR_SYNTAX);
         return;
     }
 
@@ -150,14 +120,14 @@ SASLauth(int ac, char *av[])
         return;
     }
 
-#ifdef HAVE_SSL
+#ifdef HAVE_OPENSSL
     /* Check whether STARTTLS must be used before trying to authenticate
      * with AUTHINFO SASL PLAIN, LOGIN or EXTERNAL. */
     if (PERMcanauthenticate && !PERMcanauthenticatewithoutSSL
-        && !nnrpd_starttls_done && ((strcasecmp(mech, "PLAIN") == 0
+        && !encryption_layer_on && ((strcasecmp(mech, "PLAIN") == 0
                                      || strcasecmp(mech, "LOGIN") == 0
                                      || strcasecmp(mech, "EXTERNAL") == 0))) {
-        Reply("%d Encryption required\r\n", NNTP_FAIL_PRIVACY_NEEDED);
+        Reply("%d Encryption layer required\r\n", NNTP_FAIL_PRIVACY_NEEDED);
         return;
     }
 #endif
@@ -211,7 +181,8 @@ SASLauth(int ac, char *av[])
 
 	/* Get the response from the client. */
 	r1 = line_read(&NNTPline, PERMaccessconf->clienttimeout,
-		      &clientin, (size_t *) &clientinlen, NULL);
+		      &clientin, &tclientinlen, NULL);
+        clientinlen = tclientinlen;
         
         switch (r1) {
 	case RTok:
@@ -291,26 +262,22 @@ SASLauth(int ac, char *av[])
     }
 
     if (r == SASL_OK) {
-	/* Success. */
-	strlcpy(PERMuser, canon_user, sizeof(PERMuser));
-        PERMgetpermissions();
-	PERMneedauth = false;
-	PERMauthorized = true;
-        PERMcanauthenticate = false;
+        /* Success!
+         * First, save info about the negotiated security layer
+         * for I/O functions. */
+        sasl_ssf = *ssfp;
+        sasl_maxout = (*maxoutp == 0 || *maxoutp > NNTP_MAXLEN_COMMAND) ?
+            NNTP_MAXLEN_COMMAND : *maxoutp;
 
-	syslog(L_NOTICE, "%s user %s", Client.host, PERMuser);
+        if (sasl_ssf > 1) {
+            /* For the forthcoming check of the permissions the client now
+             * has, tell the connection is encrypted, so that auth blocks
+             * requiring the negotiation of a security layer in readers.conf
+             * are properly taken into account.
+             * When sasl_ssf equals 1, only data integrity is provided, without
+             * any security. */
+            encryption_layer_on = true;
 
-	if (serveroutlen)
-	    Reply("%d %s\r\n", NNTP_OK_SASL, base64);
-	else
-	    Reply("%d Authentication succeeded\r\n", NNTP_OK_AUTHINFO);
-
-	/* Save info about the negotiated security layer for I/O functions. */
-	sasl_ssf = *ssfp;
-	sasl_maxout =
-	    (*maxoutp == 0 || *maxoutp > NNTP_MAXLEN_COMMAND) ? NNTP_MAXLEN_COMMAND : *maxoutp;
-
-        if (sasl_ssf > 0) {
             /* Close out any existing article, report group stats.
              * RFC 4643 requires the reset of any knowledge about the client. */
             if (GRPcur) {
@@ -320,15 +287,33 @@ SASLauth(int ac, char *av[])
                 OVctl(OVCACHEFREE, &boolval);
                 free(GRPcur);
                 GRPcur = NULL;
-                if (ARTcount)
-                    syslog(L_NOTICE, "%s exit for AUTHINFO SASL articles %ld groups %ld",
+                if (ARTcount) {
+                    syslog(L_NOTICE,
+                           "%s exit for AUTHINFO SASL articles %ld groups %ld",
                            Client.host, ARTcount, GRPcount);
+                }
                 GRPcount = 0;
                 PERMgroupmadeinvalid = false;
-            }
 
-            /* Reset our read buffer so as to prevent plaintext command injection. */
-            line_reset(&NNTPline);
+                /* Reset our read buffer so as to prevent plaintext
+                 * command injection. */
+                line_reset(&NNTPline);
+            }
+        }
+
+        PERMgetaccess(false);
+        strlcpy(PERMuser, canon_user, sizeof(PERMuser));
+        PERMgetpermissions();
+        PERMneedauth = false;
+        PERMauthorized = true;
+        PERMcanauthenticate = false;
+
+        syslog(L_NOTICE, "%s user %s", Client.host, PERMuser);
+
+        if (serveroutlen) {
+            Reply("%d %s\r\n", NNTP_OK_SASL, base64);
+        } else {
+            Reply("%d Authentication succeeded\r\n", NNTP_OK_AUTHINFO);
         }
     } else {
 	/* Failure. */
