@@ -1,4 +1,4 @@
-/*  $Id: tls.c 9841 2015-05-02 16:27:37Z iulius $
+/*  $Id: tls.c 10090 2016-11-03 02:30:12Z eagle $
 **
 **  tls.c -- TLSv1 functions.
 **  Copyright (C) 2000 Kenichi Okada <okada@opaopa.org>.
@@ -216,7 +216,10 @@ tmp_dh_cb(SSL *s UNUSED, int export UNUSED, int keylength)
 	default:
 		/* We should check current keylength vs. requested keylength
 		 * also, this is an extremely expensive operation! */
-		dh = DH_generate_parameters(keylength, DH_GENERATOR_2, NULL, NULL);
+                dh = DH_new();
+                if (dh != NULL) {
+                    DH_generate_parameters_ex(dh, keylength, DH_GENERATOR_2, NULL);
+                }
 		r = dh;
 	}
 
@@ -241,9 +244,13 @@ verify_callback(int ok, X509_STORE_CTX * ctx)
     err = X509_STORE_CTX_get_error(ctx);
     depth = X509_STORE_CTX_get_error_depth(ctx);
 
-    X509_NAME_oneline(X509_get_subject_name(err_cert), buf, sizeof(buf));
-    if ((tls_serveractive) && (tls_loglevel >= 1))
-      Printf("Peer cert verify depth=%d %s", depth, buf);
+    if (err_cert != NULL) {
+        X509_NAME_oneline(X509_get_subject_name(err_cert), buf, sizeof(buf));
+        if ((tls_serveractive) && (tls_loglevel >= 1)) {
+            Printf("Peer cert verify depth=%d %s", depth, buf);
+        }
+    }
+    
     if (ok==0)
     {
       syslog(L_NOTICE, "verify error:num=%d:%s", err,
@@ -257,9 +264,10 @@ verify_callback(int ok, X509_STORE_CTX * ctx)
 	    verify_error = X509_V_ERR_CERT_CHAIN_TOO_LONG;
 	}
     }
-    switch (ctx->error) {
+
+    switch (err) {
     case X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT:
-	X509_NAME_oneline(X509_get_issuer_name(ctx->current_cert), buf, sizeof(buf));
+	X509_NAME_oneline(X509_get_issuer_name(err_cert), buf, sizeof(buf));
 	syslog(L_NOTICE, "issuer= %s", buf);
 	break;
     case X509_V_ERR_CERT_NOT_YET_VALID:
@@ -383,15 +391,13 @@ set_cert_stuff(SSL_CTX * ctx, char *cert_file, char *key_file)
 	    return (0);
 	}
 
-        /* Check that the key file is a real file, not readable by
-         * everyone.  If the mode is 440 or 640, make sure the group owner
-         * is the news group (to prevent the failure case of having news:users
-         * as the owner and group. */
-	if (!S_ISREG(buf.st_mode) || (buf.st_mode & 0137) != 0
-            || ((buf.st_mode & 0040) != 0 && buf.st_gid != getegid())) {
+        /* Check that the key file is a real file, isn't world-readable, and
+         * that we can read it. */
+	if (!S_ISREG(buf.st_mode) || (buf.st_mode & 0007) != 0
+            || access(key_file, R_OK) < 0) {
 	    syslog(L_ERROR, "bad ownership or permissions on private key"
-                   " '%s':  private key must be mode 640 at most, and readable"
-                   " by the news group only", key_file);
+                   " '%s': private key must be a regular file, readable by"
+                   " nnrpd, and not world-readable", key_file);
 	    return (0);
 	}
 
@@ -492,10 +498,17 @@ tls_init_serverengine(int verifydepth, int askcert, int requirecert,
     if (tls_loglevel >= 2)
       Printf("starting TLS engine");
 
+/* New functions have been introduced in OpenSSL 1.1.0. */
+#if OPENSSL_VERSION_NUMBER < 0x010100000L
     SSL_load_error_strings();
     SSLeay_add_ssl_algorithms();
-
     CTX = SSL_CTX_new(SSLv23_server_method());
+#else
+    OPENSSL_init_ssl(OPENSSL_INIT_LOAD_SSL_STRINGS
+                     | OPENSSL_INIT_LOAD_CRYPTO_STRINGS, NULL);
+    CTX = SSL_CTX_new(TLS_server_method());
+#endif
+
     if (CTX == NULL) {
       return (-1);
     };
@@ -563,11 +576,16 @@ tls_init_serverengine(int verifydepth, int askcert, int requirecert,
      }
 #endif /* HAVE_OPENSSL_ECC */
 
-    if (prefer_server_ciphers) {
 #ifdef SSL_OP_CIPHER_SERVER_PREFERENCE
+    if (prefer_server_ciphers) {
         SSL_CTX_set_options(CTX, SSL_OP_CIPHER_SERVER_PREFERENCE);
+    } else {
+#if OPENSSL_VERSION_NUMBER >= 0x0009080dfL
+        /* Function first added in OpenSSL 0.9.8m. */
+        SSL_CTX_clear_options(CTX, SSL_OP_CIPHER_SERVER_PREFERENCE);
 #endif
     }
+#endif
 
     if ((tls_proto_vect != NULL) && (tls_proto_vect->count > 0)) {
         for (i = 0; i < tls_proto_vect->count; i++) {
@@ -624,9 +642,18 @@ tls_init_serverengine(int verifydepth, int askcert, int requirecert,
         }
     }
 
-    if (!tls_compression) {
+    if (tls_compression) {
+#if defined(SSL_OP_NO_COMPRESSION) && OPENSSL_VERSION_NUMBER >= 0x0009080dfL
+        /* Function first added in OpenSSL 0.9.8m. */
+        SSL_CTX_clear_options(CTX, SSL_OP_NO_COMPRESSION);
+#endif
+    } else {
 #ifdef SSL_OP_NO_COMPRESSION
+        /* Option implemented in OpenSSL 1.0.0. */
         SSL_CTX_set_options(CTX, SSL_OP_NO_COMPRESSION);
+#elif OPENSSL_VERSION_NUMBER >= 0x00090800fL
+        /* Workaround for OpenSSL 0.9.8. */
+        sk_SSL_COMP_zero(SSL_COMP_get_compression_methods());
 #endif
     }
 
@@ -701,13 +728,15 @@ bio_dump_cb(BIO * bio, int cmd, const char *argp, int argi, long argl UNUSED,
 	return (ret);
 
     if (cmd == (BIO_CB_READ | BIO_CB_RETURN)) {
-	Printf("read from %08lX [%08lX] (%d bytes => %ld (0x%X))", (long unsigned int) bio, (long unsigned int) argp,
-		 argi, ret, (unsigned int) ret);
+        Printf("read from %08lX [%08lX] (%d bytes => %ld (0x%X))",
+               (unsigned long) bio, (unsigned long) argp,
+               argi, ret, (unsigned int) ret);
 	tls_dump(argp, (int) ret);
 	return (ret);
     } else if (cmd == (BIO_CB_WRITE | BIO_CB_RETURN)) {
-	Printf("write to %08lX [%08lX] (%d bytes => %ld (0x%X))", (long unsigned int) bio, (long unsigned int) argp,
-		 argi, ret, (unsigned int) ret);
+        Printf("write to %08lX [%08lX] (%d bytes => %ld (0x%X))",
+               (unsigned long) bio, (unsigned long) argp,
+               argi, ret, (unsigned int) ret);
 	tls_dump(argp, (int) ret);
     }
     return (ret);
