@@ -1,4 +1,4 @@
-/*  $Id: cnfs.c 9320 2011-08-06 20:43:03Z iulius $
+/*  $Id: cnfs.c 9873 2015-05-23 11:35:34Z iulius $
 **
 **  Storage manager module for Cyclic News File System method.
 */
@@ -6,7 +6,6 @@
 #include "config.h"
 #include "clibrary.h"
 #include "portable/mmap.h"
-#include "portable/time.h"
 #include <ctype.h>
 #include <errno.h>
 #include <fcntl.h>
@@ -17,6 +16,12 @@
 #include <sys/stat.h>
 #include <sys/uio.h>
 
+#ifdef HAVE_SYS_TIME_H
+# include <sys/time.h>
+#endif
+#include <time.h>
+
+#include "inn/fdflag.h"
 #include "inn/innconf.h"
 #include "inn/messages.h"
 #include "inn/mmap.h"
@@ -123,9 +128,13 @@ static bool CNFSBreakToken(TOKEN token, char *cycbuffname,
     uint32_t	uint32;
 
     if (cycbuffname == NULL || blk == NULL || cycnum == NULL) {
-        warn("CNFS: BreakToken: invalid argument: %s", cycbuffname);
-	SMseterror(SMERR_INTERNAL, "BreakToken: invalid argument");
-	return false;
+        if (cycbuffname == NULL) {
+            warn("CNFS: BreakToken: invalid argument");
+        } else {
+            warn("CNFS: BreakToken: invalid argument: %s", cycbuffname);
+        }
+        SMseterror(SMERR_INTERNAL, "BreakToken: invalid argument");
+        return false;
     }
     memcpy(cycbuffname, token.token, CNFSMAXCYCBUFFNAME);
     *(cycbuffname + CNFSMAXCYCBUFFNAME) = '\0';	/* Just to be paranoid */
@@ -596,7 +605,7 @@ static bool CNFSinit_disks(CYCBUFF *cycbuff) {
             syswarn("CNFS: ERROR opening '%s' O_RDONLY", cycbuff->path);
 	    return false;
 	} else {
-	    close_on_exec(fd, true);
+	    fdflag_close_exec(fd, true);
 	    cycbuff->fd = fd;
 	}
     }
@@ -921,15 +930,15 @@ cnfs_mapcntl(void *p, size_t length, int flags)
 
 	/* Don't thrash the system with msync()s - keep the last value
 	 * and check each time, only if the pages which we should
-	 * flush change actually flush the previous ones. Calling
+	 * flush change actually flush the previous ones.  Calling
 	 * cnfs_mapcntl(NULL, 0, MS_ASYNC) then flushes the final
-	 * piece */
+	 * piece. */
 	if (start != sstart || end != send) {
 	    if (sstart != NULL && send != NULL) {
 		msync(sstart, send - sstart, flags);
 	    }
 	    sstart = start;
-	    send = send;
+	    send = end;
 	}
     }
 }
