@@ -1,4 +1,4 @@
-/*  $Id: overview.c 8788 2009-11-15 09:27:11Z iulius $
+/*  $Id: overview.c 9658 2014-08-28 18:59:18Z iulius $
 **
 **  The implementation of the overview API.
 **
@@ -166,7 +166,7 @@ overview_add(struct overview *overview, const char *group,
         overview->overdata = buffer_new();
         buffer_resize(overview->overdata, data->overlen + 13);
     }
-    buffer_sprintf(overview->overdata, false, "%ld\t", data->number);
+    buffer_sprintf(overview->overdata, "%ld\t", data->number);
     buffer_append(overview->overdata, data->overview, data->overlen);
     buffer_append(overview->overdata, "\r\n", 2);
 
