@@ -1,4 +1,4 @@
-/*  $Id: caf.c 8626 2009-09-07 09:06:42Z iulius $
+/*  $Id: caf.c 10059 2016-09-04 12:47:12Z iulius $
 **
 **  Library routines needed for handling CAF (Crunched Article Files)
 **  Written by Richard Todd (rmtodd@mailhost.ecn.uoknor.edu) 3/24/96,
@@ -692,6 +692,7 @@ CAFCreateCAFFile(char *cfpath, ARTNUM artnum, ARTNUM tocsize,
     head.High = artnum;
     head.NumSlots = tocsize;
     head.Free = 0;
+    head.LastCleaned = time(NULL);
     head.BlockSize = CAFFindOptimalBlocksize(tocsize, estcfsize);
     head.FreeZoneIndexSize = head.BlockSize - sizeof(CAFHEADER);
     head.FreeZoneTabSize = head.FreeZoneIndexSize
@@ -979,7 +980,7 @@ CAFFinishArtWrite(int fd)
     }
     tocentry.Offset = CAF_startoffset_write;
     tocentry.Size = curpos - CAF_startoffset_write;
-    tocentry.ModTime = time((time_t *)NULL);
+    tocentry.ModTime = time(NULL);
     if (OurWrite(fd, &tocentry, sizeof(CAFTOCENT)) < 0) {
 	CAF_fd_write = 0;
 	return -1;
@@ -1433,9 +1434,9 @@ CAFClean(char *path, int verbose, double PercentFreeThreshold)
 	return -1;
     }
 
-    /* compute amount of  actual data in file. */
+    /* compute amount of actual data in file. */
     datasize = statbuf.st_size - head.StartDataBlock;
-    if (datasize <= 0) {
+    if (datasize == 0) {
 	/* nothing in the file, set percentfree==0 so won't bother cleaning */
 	percentfree = 0;
     } else {
@@ -1559,15 +1560,14 @@ CAFClean(char *path, int verbose, double PercentFreeThreshold)
 	    ** this next fseeko might actually fail, because we have buffered
 	    ** stuff that might fail on write.
 	    */
-	    if (fseeko(infile, sizeof(CAFHEADER) + head.FreeZoneTabSize,
-		       SEEK_SET) < 0) {
-		perror(path);
-		free(tocarray);
-		free(newpath);
-		fclose(infile);
-		unlink(newpath);
-		return -1;
-	    }
+            if (fseeko(infile, sizeof(CAFHEADER) + head.FreeZoneTabSize,
+                       SEEK_SET) < 0) {
+                perror(path);
+                free(tocarray);
+                free(newpath);
+                fclose(infile);
+                return -1;
+            }
 	    if (fwrite(tocarray, sizeof(CAFTOCENT), head.High - newlow + 1, infile) < head.High - newlow + 1
 		|| fflush(infile) < 0) {
 		CAFError(CAF_ERR_IO);
@@ -1682,7 +1682,9 @@ CAFClean(char *path, int verbose, double PercentFreeThreshold)
 
     /* initialize blocksize, zeroes buffer. */
     blocksize = newhead.BlockSize;
-    if (blocksize == 0) blocksize=CAF_DEFAULT_BLOCKSIZE;
+    if (blocksize == 0) {
+        blocksize=CAF_DEFAULT_BLOCKSIZE;
+    }
 
     zerobuff = xcalloc(blocksize, 1);
 
@@ -1775,7 +1777,7 @@ CAFClean(char *path, int verbose, double PercentFreeThreshold)
     /* Change what we need in new file's header. */
     newhead.Low = newlow;
     newhead.High = head.High;
-    newhead.LastCleaned = time((time_t *) NULL);
+    newhead.LastCleaned = time(NULL);
 /*    newhead.NumSlots = newtocsize; */
 /*    newhead.Free = 0; */
 
