@@ -1,4 +1,4 @@
-/*  $Id: timecaf.c 9024 2010-03-21 16:49:30Z iulius $
+/*  $Id: timecaf.c 9870 2015-05-17 17:23:07Z iulius $
 **
 **  Like the timehash storage method (and heavily inspired by it), but uses
 **  the CAF library to store multiple articles in a single file.
@@ -15,6 +15,7 @@
 #include <time.h>
 
 #include "caf.h"
+#include "inn/fdflag.h"
 #include "inn/innconf.h"
 #include "inn/messages.h"
 #include "inn/wire.h"
@@ -185,15 +186,16 @@ static char *MakePath(time_t now, const STORAGECLASS class) {
 
 static TOKEN *PathNumToToken(char *path, ARTNUM artnum) {
     int			n;
-    unsigned int        t1, t2;
+    unsigned int        tclass, t1, t2;
     STORAGECLASS        class;
     time_t              timestamp;
     static TOKEN	token;
 
-    n = sscanf(path, "timecaf-%02x/%02x/%04x.CF", (unsigned int *)&class, &t1, &t2);
+    n = sscanf(path, "timecaf-%02x/%02x/%04x.CF", &tclass, &t1, &t2);
     if (n != 3)
 	return (TOKEN *)NULL;
     timestamp = ((t1 << 8) & 0xff00) | ((t2 << 8) & 0xff0000) | ((t2 << 0) & 0xff);
+    class = tclass;
     token = MakeToken(timestamp, artnum, class, (TOKEN *)NULL);
     return &token;
 }
@@ -433,7 +435,7 @@ TOKEN timecaf_store(const ARTHANDLE article, const STORAGECLASS class) {
     }
     WritingFile.fd = fd;
     WritingFile.path = path;
-    close_on_exec(fd, true);
+    fdflag_close_exec(fd, true);
     result = xwritev(fd, article.iov, article.iovcnt);
     if (result != (ssize_t) article.len) {
 	SMseterror(SMERR_UNDEFINED, NULL);
