@@ -1,4 +1,4 @@
-/* $Id: confparse-t.c 9764 2014-12-07 20:54:31Z iulius $ */
+/* $Id: confparse-t.c 10013 2016-05-05 12:41:49Z iulius $ */
 /* confparse test suite. */
 
 #include "config.h"
@@ -18,7 +18,7 @@
 static char *
 read_section(FILE *file)
 {
-    char buf[1024] = "";
+    char buf[1024];
     char *data = NULL;
     char *status;
 
