@@ -1,9 +1,9 @@
-/* $Id: getaddrinfo-t.c 9883 2015-05-25 10:03:20Z iulius $
+/* $Id: getaddrinfo-t.c 10106 2016-11-04 22:45:10Z iulius $
  *
  * getaddrinfo test suite.
  *
  * The canonical version of this file is maintained in the rra-c-util package,
- * which can be found at <http://www.eyrie.org/~eagle/software/rra-c-util/>.
+ * which can be found at <https://www.eyrie.org/~eagle/software/rra-c-util/>.
  *
  * Written by Russ Allbery <eagle@eyrie.org>
  *
@@ -262,7 +262,7 @@ main(void)
     is_int(0, saddr->sin_port, "...port is 0");
     first = ai;
     for (found = 0; ai != NULL; ai = ai->ai_next) {
-        if (!strcmp(ai->ai_canonname, first->ai_canonname) == 0) {
+        if (strcmp(ai->ai_canonname, first->ai_canonname) != 0) {
             ok(0, "...canonname matches");
             break;
         }
