@@ -1,4 +1,4 @@
-/* $Id: innconf-t.c 9280 2011-07-17 19:36:24Z iulius $ */
+/* $Id: innconf-t.c 9686 2014-09-07 14:13:32Z iulius $ */
 /* innconf test suite. */
 
 #include "config.h"
@@ -6,7 +6,8 @@
 
 #include "inn/innconf.h"
 #include "inn/messages.h"
-#include "libtest.h"
+#include "tap/basic.h"
+#include "tap/messages.h"
 
 /* We will have strings, integers, bools and lists. */
 static const char grep[] =
