@@ -1,4 +1,4 @@
-/* $Id: pwrite-t.c 6838 2004-05-19 06:11:42Z rra $ */
+/* $Id: pwrite-t.c 9669 2014-09-03 17:18:22Z iulius $ */
 /* pwrite test suite. */
 
 #include "config.h"
@@ -8,7 +8,7 @@
 #include <sys/stat.h>
 
 #include "inn/messages.h"
-#include "libtest.h"
+#include "tap/basic.h"
 
 ssize_t test_pwrite(int fd, const void *buf, size_t nbyte, off_t offset);
 
