@@ -1,4 +1,4 @@
-/* $Id: wire-t.c 8788 2009-11-15 09:27:11Z iulius $ */
+/* $Id: wire-t.c 9669 2014-09-03 17:18:22Z iulius $ */
 /* wire test suite. */
 
 #include "config.h"
@@ -9,7 +9,7 @@
 #include "inn/messages.h"
 #include "inn/wire.h"
 #include "inn/libinn.h"
-#include "libtest.h"
+#include "tap/basic.h"
 
 /* Read in a file and return the contents in newly allocated memory.  Fills in
    the provided stat buffer. */
