@@ -1,4 +1,4 @@
-/* $Id: api-t.c 9908 2015-06-25 20:00:51Z iulius $ */
+/* $Id: api-t.c 10015 2016-05-05 12:43:09Z iulius $ */
 /* Test suite for overview API. */
 
 #include "config.h"
@@ -140,7 +140,7 @@ overview_data_parse(char *data, unsigned long *artnum)
     *start = '\0';
     start++;
     *artnum = strtoul(start, NULL, 10);
-    if (artnum == 0)
+    if (*artnum == 0)
         die("Cannot parse article number in input data");
     return start;
 }
@@ -393,8 +393,10 @@ overview_verify_search(const char *data, struct overview *overview)
     if (overdata == NULL)
         sysdie("Cannot open %s for reading", data);
     expected = vector_new();
-    if (fgets(buffer, sizeof(buffer), overdata) == NULL)
+    if (fgets(buffer, sizeof(buffer), overdata) == NULL) {
+        fclose(overdata);
         die("Unexpected end of file in %s", data);
+    }
     overview_data_parse(buffer, &artnum);
     group = xstrdup(buffer);
     while (fgets(buffer, sizeof(buffer), overdata) != NULL) {
@@ -412,6 +414,7 @@ overview_verify_search(const char *data, struct overview *overview)
         warn("Unable to open search for %s:%lu", buffer, start);
         free(group);
         vector_free(expected);
+        fclose(overdata);
         return false;
     }
     i = 0;
@@ -432,6 +435,7 @@ overview_verify_search(const char *data, struct overview *overview)
     }
     free(group);
     vector_free(expected);
+    fclose(overdata);
     return status;
 }
 
@@ -470,6 +474,7 @@ overview_verify_full_search(const char *data, struct overview *overview)
         warn("Unable to open full search for %s", group);
         free(group);
         vector_free(expected);
+        fclose(overdata);
         return false;
     }
     i = 0;
@@ -490,6 +495,7 @@ overview_verify_full_search(const char *data, struct overview *overview)
     }
     free(group);
     vector_free(expected);
+    fclose(overdata);
     return status;
 }
 
